stm32-metapac

Crates

git

Versions

stm32h7s7l8

Flavors

Crcsaddr

Struct Crcsaddr 

#[repr(transparent)]
pub struct Crcsaddr(pub u32);
FLASH CRC start address register.

Tuple Fields

0: u32

Implementations



impl Crcsaddr

pub const fn crc_start_addr(&self) -> u16

CRC start address This register is used when CRC_BY_SECT is cleared. It must be programmed to the address of the first Flash word to use for the CRC calculation, done burst by burst. CRC computation starts at an address aligned to the burst size defined in CRC_BURST of FLASH_CRCCR register. Hence least significant bits [5:0] of the address are set by hardware to 0 (minimum burst size= 64 bytes). The address is relative to the Flash bank.

pub const fn set_crc_start_addr(&mut self, val: u16)

CRC start address This register is used when CRC_BY_SECT is cleared. It must be programmed to the address of the first Flash word to use for the CRC calculation, done burst by burst. CRC computation starts at an address aligned to the burst size defined in CRC_BURST of FLASH_CRCCR register. Hence least significant bits [5:0] of the address are set by hardware to 0 (minimum burst size= 64 bytes). The address is relative to the Flash bank.